%define major     1
%define libname   %mklibname %{name} %{major}
%define libnamepp %mklibname %{name}pp %{major}
%define develname %mklibname %{name} -d

%define _disable_ld_no_undefined 1

Name:           mosquitto
Version:        2.0.21
Release:        %mkrel 1
Summary:        An Open Source MQTT Broker
Group:          System/Libraries
License:        EPL-2.0
URL:            https://mosquitto.org/
Source0:        https://mosquitto.org/files/source/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  tcp_wrappers-devel
BuildRequires:  uthash-devel >= 2.1.0
BuildRequires:  pkgconfig(libcjson)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)

Requires(pre):  shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

The Mosquitto project also provides a C library for implementing MQTT clients,
and the very popular mosquitto_pub and mosquitto_sub command line MQTT clients.

#------------------------------------------------

%package -n     %{libname}
Summary:        An Open Source MQTT Broker
Group:          System/Libraries

%description -n %{libname}
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

#------------------------------------------------

%package -n     %{libnamepp}
Summary:        An Open Source MQTT Broker
Group:          System/Libraries

%description -n %{libnamepp}
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libnamepp} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%autosetup -p1

# Set the install prefix to /usr
sed -i "s|prefix?=/usr/local|prefix?=/usr|" config.mk
# Don't strip binaries on install: rpmbuild will take care of it
sed -i "s|(INSTALL) -s|(INSTALL)|g" lib/Makefile src/Makefile client/Makefile

%build
%cmake -DWITH_BUNDLED_DEPS=OFF -DWITH_SYSTEMD=ON -DWITH_WEBSOCKETS=ON -DWITH_SRV=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 service/systemd/%{name}.service.notify %{buildroot}%{_unitdir}/%{name}.service

%check
#make test

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sysconfdir}/%{name} -s /sbin/nologin \
    -c "Mosquitto Broker" %{name}
exit 0

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%doc ChangeLog.txt CONTRIBUTING.md README.md
%license LICENSE.txt
%{_bindir}/*
%{_sbindir}/*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/*.example
%{_unitdir}/%{name}.service
%{_mandir}/man1/*.1.*
%{_mandir}/man5/*.5.*
%{_mandir}/man7/*.7.*
%{_mandir}/man8/*.8.*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{libnamepp}
%{_libdir}/lib%{name}pp.so.%{major}{,.*}
%{_libdir}/lib%{name}pp.so.%{version}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*


%changelog
* Wed Mar 19 2025 daviddavid <daviddavid> 2.0.21-1.mga9
+ Revision: 2166491
- new version: 2.0.21, fixes CVE-2023-28366 (mga#34116)

* Tue Oct 25 2022 papoteur <papoteur> 2.0.15-2.mga9
+ Revision: 1899227
- Rebuild for libwebsockets 4.3.2

* Sat Aug 27 2022 papoteur <papoteur> 2.0.15-1.mga9
+ Revision: 1880934
- new 2.0.15

* Wed Mar 30 2022 umeabot <umeabot> 2.0.12-3.mga9
+ Revision: 1833644
- Mageia 9 Mass Rebuild
+ danf <danf>
- Switch to HTTPS URLs

* Sat Oct 02 2021 wally <wally> 2.0.12-2.mga9
+ Revision: 1748095
- rebuild for openssl 3.0.0

* Sat Sep 11 2021 neoclust <neoclust> 2.0.12-1.mga9
+ Revision: 1745213
- New version 2.0.12

* Sun Jun 27 2021 luigiwalser <luigiwalser> 2.0.11-1.mga9
+ Revision: 1734025
- 2.0.11

* Tue Apr 20 2021 daviddavid <daviddavid> 2.0.10-2.mga9
+ Revision: 1717567
- rebuild for new libwebsockets 4.2.0

* Tue Apr 06 2021 daviddavid <daviddavid> 2.0.10-1.mga9
+ Revision: 1713910
- new version: 2.0.10

* Fri Mar 12 2021 daviddavid <daviddavid> 2.0.9-1.mga9
+ Revision: 1701637
- new version: 2.0.9

* Wed Mar 03 2021 daviddavid <daviddavid> 2.0.8-1.mga9
+ Revision: 1697183
- new version: 2.0.8

* Thu Feb 25 2021 daviddavid <daviddavid> 2.0.7-1.mga9
+ Revision: 1690741
- new version: 2.0.7

* Thu Dec 24 2020 daviddavid <daviddavid> 2.0.4-1.mga8
+ Revision: 1663387
- new version: 2.0.4

* Sat Dec 19 2020 daviddavid <daviddavid> 2.0.3-1.mga8
+ Revision: 1661107
- new version: 2.0.3
- enable DNS SRV record support

* Sat Sep 12 2020 daviddavid <daviddavid> 1.6.12-3.mga8
+ Revision: 1624898
- really enable websockets support

* Sat Sep 12 2020 daviddavid <daviddavid> 1.6.12-2.mga8
+ Revision: 1624887
- rebuild for new libwebsockets 4.1.0

* Tue Aug 25 2020 daviddavid <daviddavid> 1.6.12-1.mga8
+ Revision: 1618840
- new version: 1.6.12

* Tue Aug 18 2020 daviddavid <daviddavid> 1.6.11-1.mga8
+ Revision: 1614722
- new version: 1.6.11

* Mon Jul 20 2020 daviddavid <daviddavid> 1.6.10-3.mga8
+ Revision: 1607310
- compile with system uthash (adding -DWITH_BUNDLED_DEPS=OFF)

* Sun Jul 19 2020 ovitters <ovitters> 1.6.10-2.mga8
+ Revision: 1607271
- enable systemd support (systemd unit assumed this)

* Thu May 28 2020 daviddavid <daviddavid> 1.6.10-1.mga8
+ Revision: 1588296
- new version: 1.6.10

* Thu Mar 12 2020 daviddavid <daviddavid> 1.6.9-2.mga8
+ Revision: 1555735
- rebuild for new libwebsockets 4.0.1

* Mon Mar 09 2020 daviddavid <daviddavid> 1.6.9-1.mga8
+ Revision: 1555033
- new version: 1.6.9

* Tue Feb 18 2020 umeabot <umeabot> 1.6.8-2.mga8
+ Revision: 1539230
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Wed Dec 04 2019 daviddavid <daviddavid> 1.6.8-1.mga8
+ Revision: 1464219
- new version: 1.6.8

* Wed Sep 25 2019 daviddavid <daviddavid> 1.6.7-1.mga8
+ Revision: 1445983
- new version: 1.6.7
- new version: 1.6.6

* Mon Aug 19 2019 daviddavid <daviddavid> 1.6.4-2.mga8
+ Revision: 1430288
- rebuild for new libwebsockets 3.2.0

* Sat Aug 03 2019 daviddavid <daviddavid> 1.6.4-1.mga8
+ Revision: 1426991
- new version: 1.6.4

* Sun Jun 30 2019 daviddavid <daviddavid> 1.6.3-1.mga8
+ Revision: 1416244
- new version: 1.6.3

* Thu Apr 18 2019 daviddavid <daviddavid> 1.6.0-1.mga7
+ Revision: 1393283
- new version: 1.6.0

* Sat Mar 02 2019 daviddavid <daviddavid> 1.5.8-1.mga7
+ Revision: 1371000
- new version: 1.5.8

* Sun Feb 17 2019 daviddavid <daviddavid> 1.5.7-1.mga7
+ Revision: 1367860
- new version: 1.5.7

* Sat Feb 09 2019 daviddavid <daviddavid> 1.5.6-1.mga7
+ Revision: 1364447
- new version: 1.5.6

* Sat Dec 15 2018 daviddavid <daviddavid> 1.5.5-1.mga7
+ Revision: 1341327
- new version: 1.5.5

* Sat Nov 24 2018 daviddavid <daviddavid> 1.5.4-2.mga7
+ Revision: 1333910
- rebuild for new libwebsockets 3.1.0

* Tue Nov 13 2018 daviddavid <daviddavid> 1.5.4-1.mga7
+ Revision: 1329705
- new version: 1.5.4

* Thu Oct 11 2018 daviddavid <daviddavid> 1.5.3-1.mga7
+ Revision: 1319505
- new version: 1.5.3

* Fri Sep 21 2018 daviddavid <daviddavid> 1.5.2-1.mga7
+ Revision: 1294636
- new version: 1.5.2

* Tue Aug 21 2018 daviddavid <daviddavid> 1.5.1-1.mga7
+ Revision: 1253205
- new version: 1.5.1

* Sun May 27 2018 daviddavid <daviddavid> 1.5-2.mga7
+ Revision: 1232367
- use upstream systemd service and enable systemd notification support
- add network-online.target and documentation to unitfile

* Mon May 21 2018 daviddavid <daviddavid> 1.5-1.mga7
+ Revision: 1230998
- initial package mosquitto

